# nec_beamer_control

Command Line Interface for a NEC Beamer Web UI.
This is implemented with the NEC Beamer NP2000

Web Interface has a Copyright (C) NEC Viewtechnology, Ltd. 2002-2006

This is the async version of nec_beamer.
